@@ -14,7 +14,7 @@ from yapic import json
 from cryptofeed.backends._util import book_flatten
 from cryptofeed.backends.backend import (BackendBookCallback, BackendBookDeltaCallback, BackendCandlesCallback, BackendFundingCallback,
                                          BackendOpenInterestCallback, BackendTickerCallback, BackendTradeCallback,
-                                         BackendLiquidationsCallback, BackendMarketInfoCallback)
+                                         BackendLiquidationsCallback)
 from cryptofeed.backends.http import HTTPCallback
 
 
@@ -102,9 +102,5 @@ class LiquidationsElastic(ElasticCallback, BackendLiquidationsCallback):
     default_index = 'liquidations'
 
 
-class MarketInfoElastic(ElasticCallback, BackendMarketInfoCallback):
-    default_index = 'market_info'
-
-
 class CandlesElastic(ElasticCallback, BackendCandlesCallback):
     default_index = 'candles'
