@@ -25,7 +25,6 @@ from cryptofeed.backends.backend import (
     BackendBookDeltaCallback, BackendCandlesCallback,
     BackendFundingCallback,
     BackendLiquidationsCallback,
-    BackendMarketInfoCallback,
     BackendOpenInterestCallback,
     BackendTickerCallback,
     BackendTradeCallback,
@@ -134,9 +133,5 @@ class LiquidationsGCPPubSub(GCPPubSubCallback, BackendLiquidationsCallback):
     default_key = 'liquidations'
 
 
-class MarketInfoGCPPubSub(GCPPubSubCallback, BackendMarketInfoCallback):
-    default_key = 'market_info'
-
-
 class CandlesGCPPubSub(GCPPubSubCallback, BackendCandlesCallback):
     default_key = 'candles'
