@@ -10,7 +10,7 @@ from yapic import json
 
 from cryptofeed.backends.backend import (BackendBookCallback, BackendBookDeltaCallback, BackendCandlesCallback, BackendFundingCallback,
                                          BackendOpenInterestCallback, BackendTickerCallback, BackendTradeCallback,
-                                         BackendLiquidationsCallback, BackendMarketInfoCallback)
+                                         BackendLiquidationsCallback)
 from cryptofeed.backends.http import HTTPCallback
 from cryptofeed.defines import BID, ASK
 
@@ -121,9 +121,5 @@ class LiquidationsInflux(InfluxCallback, BackendLiquidationsCallback):
     default_key = 'liquidations'
 
 
-class MarketInfoInflux(InfluxCallback, BackendMarketInfoCallback):
-    default_key = 'market_info'
-
-
 class CandlesInflux(InfluxCallback, BackendCandlesCallback):
     default_key = 'candles'
