@@ -10,7 +10,7 @@ import motor.motor_asyncio
 
 from cryptofeed.backends.backend import (BackendBookCallback, BackendBookDeltaCallback, BackendCandlesCallback, BackendFundingCallback,
                                          BackendOpenInterestCallback, BackendTickerCallback, BackendTradeCallback,
-                                         BackendLiquidationsCallback, BackendMarketInfoCallback)
+                                         BackendLiquidationsCallback)
 
 
 class MongoCallback:
@@ -56,9 +56,5 @@ class LiquidationsMongo(MongoCallback, BackendLiquidationsCallback):
     default_key = 'liquidations'
 
 
-class MarketInfoMongo(MongoCallback, BackendMarketInfoCallback):
-    default_key = 'market_info'
-
-
 class CandlesMongo(MongoCallback, BackendCandlesCallback):
     default_key = 'candles'
