@@ -11,7 +11,7 @@ from yapic import json
 
 from cryptofeed.backends.backend import (BackendBookCallback, BackendBookDeltaCallback, BackendCandlesCallback, BackendFundingCallback,
                                          BackendOpenInterestCallback, BackendTickerCallback, BackendTradeCallback,
-                                         BackendLiquidationsCallback, BackendMarketInfoCallback)
+                                         BackendLiquidationsCallback)
 
 
 class RabbitCallback:
@@ -101,9 +101,5 @@ class LiquidationsRabbit(RabbitCallback, BackendLiquidationsCallback):
     pass
 
 
-class MarketInfoRabbit(RabbitCallback, BackendMarketInfoCallback):
-    pass
-
-
 class CandlesRabbit(RabbitCallback, BackendCandlesCallback):
     pass
