@@ -12,7 +12,7 @@ from yapic import json
 
 from cryptofeed.backends.backend import (BackendCandlesCallback, BackendQueue, BackendBookCallback, BackendBookDeltaCallback, BackendFundingCallback,
                                          BackendOpenInterestCallback, BackendTickerCallback, BackendTradeCallback,
-                                         BackendLiquidationsCallback, BackendMarketInfoCallback)
+                                         BackendLiquidationsCallback)
 
 
 LOG = logging.getLogger('feedhandler')
@@ -130,9 +130,5 @@ class LiquidationsSocket(SocketCallback, BackendLiquidationsCallback):
     default_key = 'liquidations'
 
 
-class MarketInfoSocket(SocketCallback, BackendMarketInfoCallback):
-    default_key = 'market_info'
-
-
 class CandlesSocket(SocketCallback, BackendCandlesCallback):
     default_key = 'candles'
