@@ -8,7 +8,7 @@ import logging
 
 from cryptofeed.backends.backend import (BackendBookCallback, BackendBookDeltaCallback, BackendCandlesCallback, BackendFundingCallback,
                                          BackendOpenInterestCallback, BackendTickerCallback, BackendTradeCallback,
-                                         BackendLiquidationsCallback, BackendMarketInfoCallback)
+                                         BackendLiquidationsCallback)
 from cryptofeed.backends.socket import SocketCallback
 from cryptofeed.defines import BID, ASK
 from typing import Optional
@@ -131,9 +131,5 @@ class LiquidationsVictoriaMetrics(VictoriaMetricsCallback, BackendLiquidationsCa
     default_key = 'liquidations'
 
 
-class MarketInfoVictoriaMetrics(VictoriaMetricsCallback, BackendMarketInfoCallback):
-    default_key = 'market_info'
-
-
 class CandlesVictoriaMetrics(VictoriaMetricsCallback, BackendCandlesCallback):
     default_key = 'candles'
