@@ -10,7 +10,7 @@ from yapic import json
 
 from cryptofeed.backends.backend import (BackendCandlesCallback, BackendQueue, BackendBookCallback, BackendBookDeltaCallback, BackendFundingCallback,
                                          BackendOpenInterestCallback, BackendTickerCallback, BackendTradeCallback,
-                                         BackendLiquidationsCallback, BackendMarketInfoCallback)
+                                         BackendLiquidationsCallback)
 
 
 class ZMQCallback(BackendQueue):
@@ -63,9 +63,5 @@ class LiquidationsZMQ(ZMQCallback, BackendLiquidationsCallback):
     default_key = 'liquidations'
 
 
-class MarketInfoZMQ(ZMQCallback, BackendMarketInfoCallback):
-    default_key = 'market_info'
-
-
 class CandlesZMQ(ZMQCallback, BackendCandlesCallback):
     default_key = 'candles'
