@@ -4,22 +4,60 @@ Copyright (C) 2017-2021  Bryant Moscon - bmoscon@gmail.com
 Please see the LICENSE file for the terms and conditions
 associated with this software.
 '''
-import asyncio
 import logging
-from contextlib import asynccontextmanager
 import time
-from typing import List, Union, AsyncIterable
+from functools import wraps
+import asyncio
+from asyncio import Queue, create_task
+from contextlib import asynccontextmanager
+from typing import List, Union, AsyncIterable, Optional
+from decimal import Decimal
 
-import aiohttp
-import websockets
 import requests
+import websockets
+import aiohttp
+from aiohttp.typedefs import StrOrURL
+from yapic import json as json_parser
 
-from cryptofeed.exceptions import ConnectionClosed
+from cryptofeed.exceptions import ConnectionClosed, ConnectionExists
 
 
 LOG = logging.getLogger('feedhandler')
 
 
+def request_retry(exchange, retry, retry_wait):
+    """
+    decorator to retry request
+    """
+    def wrap(f):
+        @wraps(f)
+        def wrapped_f(*args, **kwargs):
+            retry_count = retry
+            while True:
+                try:
+                    return f(*args, **kwargs)
+                except TimeoutError as e:
+                    LOG.warning("%s: Timeout - %s", exchange, e)
+                    if retry_count is not None:
+                        if retry_count == 0:
+                            raise
+                        else:
+                            retry_count -= 1
+                    time.sleep(retry_wait)
+                    continue
+                except requests.exceptions.ConnectionError as e:
+                    LOG.warning("%s: Connection error - %s", exchange, e)
+                    if retry_count is not None:
+                        if retry_count == 0:
+                            raise
+                        else:
+                            retry_count -= 1
+                    time.sleep(retry_wait)
+                    continue
+        return wrapped_f
+    return wrap
+
+
 class Connection:
     raw_data_callback = None
 
@@ -36,7 +74,7 @@ class HTTPSync(Connection):
             self.raw_data_callback.sync_callback(r.text, time.time(), str(uuid), endpoint=address)
         r.raise_for_status()
         if json:
-            return r.json()
+            return json_parser.loads(r.text, parse_float=Decimal)
         if text:
             return r.text
         return r
@@ -95,12 +133,15 @@ class AsyncConnection(Connection):
 
 
 class HTTPAsyncConn(AsyncConnection):
-    def __init__(self, conn_id: str):
+    def __init__(self, conn_id: str, proxy: StrOrURL = None):
         """
         conn_id: str
             id associated with the connection
+        proxy: str, URL
+            proxy url (GET only)
         """
         super().__init__(f'{conn_id}.http.{self.conn_count}')
+        self.proxy = proxy
 
     @property
     def is_open(self) -> bool:
@@ -121,7 +162,7 @@ class HTTPAsyncConn(AsyncConnection):
 
         LOG.debug("%s: requesting data from %s", self.id, address)
         while True:
-            async with self.conn.get(address, headers=header) as response:
+            async with self.conn.get(address, headers=header, proxy=self.proxy) as response:
                 data = await response.text()
                 self.last_message = time.time()
                 self.received += 1
@@ -150,8 +191,8 @@ class HTTPAsyncConn(AsyncConnection):
 
 
 class HTTPPoll(HTTPAsyncConn):
-    def __init__(self, address: Union[List, str], conn_id: str, delay: float = 60, sleep: float = 1):
-        super().__init__(f'{conn_id}.http.{self.conn_count}')
+    def __init__(self, address: Union[List, str], conn_id: str, delay: float = 60, sleep: float = 1, proxy: StrOrURL = None):
+        super().__init__(f'{conn_id}.http.{self.conn_count}', proxy)
         if isinstance(address, str):
             address = [address]
         self.address = address
@@ -159,27 +200,60 @@ class HTTPPoll(HTTPAsyncConn):
         self.sleep = sleep
         self.delay = delay
 
-    async def read(self, header=None) -> AsyncIterable:
+    async def _read_address(self, address: str, header=None) -> str:
+        if not self.is_open:
+            LOG.error('%s: connection closed in read()', self.id)
+            raise ConnectionClosed
+        LOG.debug("%s: polling %s", self.id, address)
+        while True:
+            async with self.conn.get(address, headers=header, proxy=self.proxy) as response:
+                data = await response.text()
+                self.received += 1
+                self.last_message = time.time()
+                if self.raw_data_callback:
+                    await self.raw_data_callback(data, self.last_message, self.id, endpoint=address)
+                if response.status != 429:
+                    response.raise_for_status()
+                    return data
+            LOG.warning("%s: encountered a rate limit for address %s, retrying in %f seconds", self.id, address, self.delay)
+            await asyncio.sleep(self.delay)
+
+    async def read(self, header=None) -> AsyncIterable[str]:
         while True:
             for addr in self.address:
-                if not self.is_open:
-                    LOG.error('%s: connection closed in read()', self.id)
-                    raise ConnectionClosed
-                LOG.debug("%s: polling %s", self.id, addr)
-                async with self.conn.get(addr, headers=header) as response:
-                    data = await response.text()
-                    self.received += 1
-                    self.last_message = time.time()
-                    if self.raw_data_callback:
-                        await self.raw_data_callback(data, self.last_message, self.id, endpoint=addr)
-                    if response.status == 429:
-                        LOG.warning("%s: encountered a rate limit for address %s, retrying in %f seconds", self.id, addr, self.delay)
-                        await asyncio.sleep(self.delay)
-                        continue
-                    response.raise_for_status()
-                    yield data
-                    await asyncio.sleep(self.sleep)
-            await asyncio.sleep(self.delay)
+                yield await self._read_address(addr, header)
+            await asyncio.sleep(self.sleep)
+
+
+class HTTPConcurrentPoll(HTTPPoll):
+    """Polls each address concurrently in it's own Task"""
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._queue: Optional[Queue] = None
+
+    async def _poll_address(self, address: str, header=None):
+        try:
+            while True:
+                data = await self._read_address(address, header)
+                await asyncio.gather(self._queue.put(data), asyncio.sleep(self.sleep))
+        except Exception as e:
+            await self._queue.put(e)
+
+    async def read(self, header=None) -> AsyncIterable[str]:
+        if self._queue:
+            raise ConnectionExists('Only one reader allowed per poll')
+
+        self._queue = Queue()
+
+        for address in self.address:
+            create_task(self._poll_address(address, header))
+
+        while True:
+            data = await self._queue.get()
+            if isinstance(data, Exception):
+                raise data
+            yield data
 
 
 class WSAsyncConn(AsyncConnection):
@@ -216,7 +290,7 @@ class WSAsyncConn(AsyncConnection):
 
     async def read(self) -> AsyncIterable:
         if not self.is_open:
-            LOG.error('%s: connection closed in read()', self.id)
+            LOG.error('%s: connection closed in read()', id(self))
             raise ConnectionClosed
         if self.raw_data_callback:
             async for data in self.conn:
@@ -232,7 +306,6 @@ class WSAsyncConn(AsyncConnection):
 
     async def write(self, data: str):
         if not self.is_open:
-            LOG.error('%s: connection closed in write()', self.id)
             raise ConnectionClosed
 
         if self.raw_data_callback:
