@@ -48,3 +48,11 @@ class RestResponseError(Exception):
 
 class ConnectionClosed(Exception):
     pass
+
+
+class UnexpectedMessage(Exception):
+    pass
+
+
+class ConnectionExists(Exception):
+    pass
